import 'package:equatable/equatable.dart';

abstract class DeleteAccountState extends Equatable {
  const DeleteAccountState();

  @override
  List<Object> get props => [];
}

class DeleteAccountInitial extends DeleteAccountState {}

class DeleteAccountLoading extends DeleteAccountState {}

class DeleteAccountSuccess extends DeleteAccountState {}

class DeleteAccountFailure extends DeleteAccountState {
  final String error;

  const DeleteAccountFailure(this.error);

  @override
  List<Object> get props => [error];
}

class DeleteAccountFieldsState extends DeleteAccountState {
  final bool areFieldsFilled;

  const DeleteAccountFieldsState(this.areFieldsFilled);

  @override
  List<Object> get props => [areFieldsFilled];
}
